@@ -129,7 +129,7 @@ def segment(reference_image_filepath, merged_composite_filepath, input_directory
         pipeline_filepath = str(PurePath(__file__).parent / "segment.cppipe")
 
     subprocess.run(["cellprofiler", "-c", "-p", pipeline_filepath, "-i", input_directory, "-o", input_directory])
-    subprocess.run(["mv", "output/composite_mask.tiff", output_directory])
+    subprocess.run(["mv", "output/composite_mask.tiff", merged_composite_filepath])
     subprocess.run(["rm", "-rf", "output/"])
     
     # segmentation_pipeline = pipeline.Pipeline()
